﻿using System;
using System.Windows.Forms;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace  CustomTrackPolygon
{
    public partial class TestForm : Form
    {
        public TestForm()
        {
            InitializeComponent();
        }

        private void TestForm_Load(object sender, EventArgs e)
        {
            label1.Text = "Left click to track polygon. Right click to remove last vertex.";

            winformsMap1.TrackOverlay = new CustomTrackInteractiveOverlay();
            winformsMap1.TrackOverlay.TrackStarted += TrackOverlay_TrackStarted;
            winformsMap1.TrackOverlay.TrackEnded += TrackOverlay_TrackEnded;
           
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.CurrentExtent = new RectangleShape(-95.2957, 38.9791, -95.2397, 38.9452);
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 198, 255, 255));

            //Displays the World Map Kit as a background.
            WorldMapKitWmsDesktopOverlay worldMapKitDesktopOverlay = new WorldMapKitWmsDesktopOverlay();
            winformsMap1.Overlays.Add(worldMapKitDesktopOverlay);

            winformsMap1.Refresh();
        }
         
        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        void TrackOverlay_TrackStarted(object sender, TrackStartedTrackInteractiveOverlayEventArgs e)
        {
            // clear any shapes in edit overlay
            ClearEditOverlay();
        }

        void TrackOverlay_TrackEnded(object sender, TrackEndedTrackInteractiveOverlayEventArgs e)
        {
            BaseShape baseShape = e.TrackShape;
            Feature feature = new Feature(baseShape);

            ClearTrackOverlay();

            winformsMap1.EditOverlay.EditShapesLayer.InternalFeatures.Add(feature);

            // this throws exception
            try
            {
                winformsMap1.Refresh(new Overlay[] { winformsMap1.EditOverlay });
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }
        }

        private void ClearTrackOverlay()
        {
            winformsMap1.TrackOverlay.TrackShapeLayer.InternalFeatures.Clear();
            winformsMap1.Refresh(new Overlay[] { winformsMap1.TrackOverlay });
        }

        private void btnEdit_Click(object sender, EventArgs e)
        {
            winformsMap1.EditOverlay.CalculateAllControlPoints();

            winformsMap1.Refresh(new Overlay[] { winformsMap1.EditOverlay });
        }

        private void ClearEditOverlay()
        {
            winformsMap1.EditOverlay.EditShapesLayer.InternalFeatures.Clear();

            // need this to clear edit drag/resize controls
            winformsMap1.EditOverlay.ExistingControlPointsLayer.InternalFeatures.Clear();
            winformsMap1.EditOverlay.ResizeControlPointsLayer.InternalFeatures.Clear();
            winformsMap1.EditOverlay.RotateControlPointsLayer.InternalFeatures.Clear();
            winformsMap1.EditOverlay.DragControlPointsLayer.InternalFeatures.Clear();

            winformsMap1.Refresh(new Overlay[] { winformsMap1.EditOverlay });
        }

    }
}
